/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
\file terralib/qt/widgets/se/LinePerpendicularOffsetPropertyItem.cpp

\brief A widget used to define the Perpendicular Offset between a line and marks.
*/


#include "../../../common/StringUtils.h"
#include "../../../se/SvgParameter.h"
#include "../../../se/Utils.h"
#include "../propertybrowser/AbstractPropertyManager.h"
#include "LinePerpendicularOffsetPropertyItem.h"

// STL
#include <cassert>


te::qt::widgets::LinePerpendicularOffsetPropertyItem::LinePerpendicularOffsetPropertyItem(QtTreePropertyBrowser* pb, QColor c) : 
  te::qt::widgets::AbstractPropertyItem(pb, c),
  m_offset(0.0),
  m_update(false)
{
  //offset
  m_perpendicularOffset = te::qt::widgets::AbstractPropertyManager::getInstance().m_doubleManager->addProperty(tr("Offset"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_doubleManager->setValue(m_perpendicularOffset, m_offset);
  
  addProperty(m_perpendicularOffset, tr("Offset"), QColor(175, 255, 175));

  m_update = true;
}

te::qt::widgets::LinePerpendicularOffsetPropertyItem::~LinePerpendicularOffsetPropertyItem()
{
  delete m_perpendicularOffset;
}

void te::qt::widgets::LinePerpendicularOffsetPropertyItem::valueChanged(QtProperty* p, double value)
{
  if (!m_update)
    return;

  if (p == m_perpendicularOffset)
  {
    m_update = false;

    m_offset = value;
    
    emit linePerpendicularOffsetChanged();
    m_update = true;
  }
}

void te::qt::widgets::LinePerpendicularOffsetPropertyItem::updateUi()
{    
  te::qt::widgets::AbstractPropertyManager::getInstance().m_doubleManager->setValue(m_perpendicularOffset, m_offset);
}

void te::qt::widgets::LinePerpendicularOffsetPropertyItem::setLinePerpendicularOffset(double offset)
{
  m_offset = offset;

  updateUi();
}
  
double te::qt::widgets::LinePerpendicularOffsetPropertyItem::getLinePerpendicularOffset() const
{
  return m_offset;
}

